@@ -23,16 +23,21 @@
 
 import argparse
 import os
-from graphviz import Digraph
+try:
+    from graphviz import Digraph
+except ModuleNotFoundError:
+    pass
 from greedyFAS.mainFAS import fasPathing
 from greedyFAS.mainFAS import fasInput
 from greedyFAS.mainFAS import greedyFAS
 
 
 def get_options():
+    version = '1.4.4'
     parser = argparse.ArgumentParser()
     required = parser.add_argument_group('required arguments')
     optional = parser.add_argument_group('optional arguments')
+    parser.add_argument('--version', action='version', version=str(version))
     required.add_argument("-i", "--input", default=None, type=str, required=True,
                           help="path to protein fasta file")
     optional.add_argument("-p", "--id", default=None, nargs='*', type=str,
@@ -49,7 +54,7 @@ def get_options():
                           help="eValue cutoff for PFAM/SMART domains")
     optional.add_argument("-e", "--eInstance", default="0.01", type=float,
                           help="eValue cutoff for PFAM/SMART instances")
-    optional.add_argument("--show_graph", action='store_True',
+    optional.add_argument("--show_graph", action='store_true',
                           help="visualize the feature graph, you may need to install graphviz for this feature")
     args = parser.parse_args()
     return args
